pub trait FileSystemRead: FileSystem { // Required method fn read( &mut self, file: &File, buffer: &mut [u8], time: UtcTime, ) -> Result<usize, ()>; }
This needs to be a mutable reference, because the filesystem might need to update metadata of the file