#[repr(C)]pub struct FixedByteStr<const N: usize> {
pub raw: [u8; N],
pub len: usize,
}Expand description
A no-std compatible string type
This is a wrapper around a fixed size array of bytes The string is not null terminated, and the length is stored in the struct
Fields
raw: [u8; N]len: usizeImplementations